#include "testlib.h"

#include <iostream>
#include <cstdio>
using namespace std;

int const MAXN = 10;

int n,m;
char field[MAXN][MAXN];

int valid_char(char ch) {
	return (ch == 'u' || ch == 'U' ||
			ch == 'd' || ch == 'D' ||
			ch == 'l' || ch == 'L' ||
			ch == 'r' || ch == 'R');
}

void go_from(int start_x, int start_y, char ch, int& new_x, int& new_y) {
	if (ch == 'u' || ch == 'U') {
		new_x = start_x - 1;
		new_y = start_y;
		return;
	}

	if (ch == 'd' || ch == 'D') {
		new_x = start_x + 1;
		new_y = start_y;
		return;
	}

	if (ch == 'l' || ch == 'L') {
		new_x = start_x;
		new_y = start_y - 1;
		return;
	}

	if (ch == 'r' || ch == 'R') {
		new_x = start_x;
		new_y = start_y + 1;
		return;
	}

	new_x = start_x;
	new_y = start_y;
}

int is_outside(int x, int y) {
	return x < 0 || x >= n || y < 0 || y >= m;
}

int my_is_digit(char ch) {
	return ch >= '0' && ch <= '9';
}

int is_BIG(char ch) {
	return ch == 'U' || ch == 'D' || ch == 'L' || ch == 'R';
}

int is_correct(const string& st) {
	if (st.length() > 1000000) {
		quitf(_wa, "Wrong answer (too long line)!");
		return 0;
	}

	for (int i=0; i<(int) st.length(); i++)
		if (!valid_char(st[i])) {
			quitf(_wa, "Wrong answer (incorrect symbol <%c>)!", st[i]);
			return 0;
		}

	//---------model_movement-----------
	int start_x = -1, start_y = -1;
	for (int i=0; i<n; i++)
		for (int j=0; j<m; j++)
			if (field[i][j] == 's') {
				start_x = i;
				start_y = j;
				field[i][j] = '.';
			}
			else if (field[i][j] == 'S') {
				start_x = i;
				start_y = j;
				field[i][j] = 'x';
			}

	for (int i=0; i<(int) st.length(); i++) {
		int new_x, new_y;
		go_from(start_x, start_y, st[i], new_x, new_y);

		if (is_outside(new_x, new_y)) {
			quitf(_wa, "Wrong answer (outside of map on %d move)!", i+1);
			return 0;
		}

		if (field[new_x][new_y] == '#') {
			quitf(_wa, "Wrong answer (try to go through wall on %d move)!", i+1);
			return 0;
		}

		if (field[new_x][new_y] == '.' || field[new_x][new_y] == 'x') {
			start_x = new_x;
			start_y = new_y;

			if (is_BIG(st[i])) {
				quitf(_wa, "Wrong answer (big letter, but boxes don't move (move %d))!", i+1);
				return 0;
			}

			continue;
		}

		if (field[new_x][new_y] == 'b' || field[new_x][new_y] == 'B') {
			int mega_x, mega_y;
			go_from(new_x, new_y, st[i], mega_x, mega_y);

			if (is_outside(mega_x, mega_y)) {
				quitf(_wa, "Wrong answer (try to move box out of map on %d move)!", i+1);
				return 0;
			}

			if (field[mega_x][mega_y] == '#' || field[mega_x][mega_y] == 'b' || field[mega_x][mega_y] == 'B' ||
				my_is_digit(field[mega_x][mega_y])) {
				quitf(_wa, "Wrong answer (box can't change position on %d move)!", i+1);
				return 0;
			}

			char new_ch = '.';
			if (field[new_x][new_y] == 'B')
				new_ch = 'x';

			char mega_ch = 'b';
			if (field[mega_x][mega_y] == 'x')
				mega_ch = 'B';

			field[new_x][new_y] = new_ch;
			field[mega_x][mega_y] = mega_ch;

			start_x = new_x;
			start_y = new_y;

			if (! is_BIG(st[i])) {
				quitf(_wa, "Wrong answer (small letter, but box moves (move %d))!", i+1);
				return 0;
			}

			continue;
		}

		if (my_is_digit(field[new_x][new_y])) {
			int Ok = 0;
			for (int p=0; p<n && !Ok; p++)
				for (int q=0; q<m && !Ok; q++)
					if (field[p][q] == field[new_x][new_y] &&
						!(p == new_x && q == new_y)) {
							start_x = p;
							start_y = q;
							Ok = 1;
							break;
					}

			if (is_BIG(st[i])) {
				quitf(_wa, "Wrong answer (big letter, but boxes don't move (move %d))!", i+1);
				return 0;
			}

			continue;
		}
	}

	for (int i=0; i<n; i++)
		for (int j=0; j<m; j++)
			if (field[i][j] == 'b')
				return 0;
	//----------------------------------

	return 1;
}

int main(int argc, char *argv[]) {
	registerTestlibCmd(argc, argv);

	//--------read_input_data-----------
	string inf_str = inf.readLine();
	sscanf(inf_str.c_str(),"%d%d",&n,&m);
	for (int i=0; i<n; i++) {
		inf_str = inf.readLine();
		for (int j=0; j<m; j++)
			field[i][j] = inf_str[j];
	}
	//----------------------------------

	string contestant_str = ouf.readLine();
	
	if (is_correct(contestant_str))
		quitf(_ok, "Accepted!");
	else
		quitf(_wa, "Wrong answer!");

	return 0;
}
