#include <iostream>
#include <cstdio>
using namespace std;

int const MAX_CH = 1000;
int const MAXN = 5;

int const MAX_ANSWER_LEN = 2000000;
char answer[MAX_ANSWER_LEN];
int answer_len;

int const DX[4] = {0,0,-1,1};
int const DY[4] = {-1,1,0,0};
char const DSYM[4] = {'l','r','u','d'};

int const QUEUE_SIZE = 70000000;

unsigned int const MAX_HASH_SIZE = 12000017U;
unsigned int const HASH_CONST = 1000000009U;

unsigned int const MASK_ONE = 4294967295U;

typedef unsigned int uint;

char st[MAX_CH];
char field[MAXN][MAXN];
int n,m,dig_x[10],dig_y[10];

uint queue[QUEUE_SIZE];
int p_read, p_write;

int my_is_digit(char ch) {
	return ch>='0' && ch<='9';
}

struct point {
	uint row,column;

	point():row(0),column(0) {}
	point(uint row, uint column):row(row),column(column) {}
} start_pos, teleport_link[MAXN][MAXN];

struct code_type {
	uint code;

	code_type():code(0) {}

	void set_bit(uint x, uint y, uint value) {
		uint num = x * m + y;
		code = (code & (MASK_ONE - (1<<num))) + (value << num);
	}

	uint get_bit(uint x, uint y) {
		uint num = x * m + y;
		return (code & (1<<num)) > 0;
	}

} x_pos, box_pos;

uint encode(uint code, uint x, uint y) {
	uint ans = code<<5;
	ans += x * m + y;
	return ans;
}

void decode(uint ans, uint& code, uint& x, uint& y) {
	uint num = ans & 31;
	code = ans >> 5;
	x = num / m;
    y = num - x * m;
}

struct my_list {
	uint total_code;
	
	my_list *from;
	my_list *next;
};

struct ht {
	my_list *s[MAX_HASH_SIZE];

	void clear() {
		for (int i=0; i<MAX_HASH_SIZE; i++)
			if (s[i]) {
				my_list *t = s[i], *tt = 0;
				while (t) {
					tt = t;
					t = t->next;
					delete tt;
				}
				s[i] = 0;
			}
	}

	ht() {
		clear();
	}

	~ht() {
		clear();
	}

	uint calc_hash_code(uint total_code) {
		return (total_code * HASH_CONST) % MAX_HASH_SIZE;
	}

	my_list* find(uint total_code) {
		uint d = calc_hash_code(total_code);

		my_list *t = s[d];
		while (t) {
			if (t->total_code == total_code)
				return t;
			t = t->next;
		}

		return 0;
	}

	void add(uint total_code, my_list* from) {
		uint d = calc_hash_code(total_code);

		my_list *t = new my_list;
		t->total_code = total_code;
		t->from = from;

		t->next = s[d];
		s[d] = t;
	}
} my_ht;

char get_symbol(int x1, int y1, int x2, int y2) {
	for (int k=0; k<4; k++) {
		int new_x = x1 + DX[k];
		int new_y = y1 + DY[k];

		if (new_x >= 0 && new_x < n && new_y >= 0 && new_y < m) {
			if (field[new_x][new_y] == '#') continue;
			
			if (my_is_digit(field[new_x][new_y])) {
				if (x2 == teleport_link[new_x][new_y].row && y2 == teleport_link[new_x][new_y].column)
					return DSYM[k];
				continue;
			}

			if (new_x == x2 && new_y == y2)
				return DSYM[k];
		}
	}
}

void recover_answer(my_list *t) {
	answer_len = 0;

	while (t->from != 0) {
		uint t_code = t->total_code;
		uint t_box_code, t_x, t_y;
		decode(t_code, t_box_code, t_x, t_y);

		uint from_code = t->from->total_code;
		uint from_box_code, from_x, from_y;
		decode(from_code, from_box_code, from_x, from_y);

		char ch = get_symbol(from_x, from_y, t_x, t_y);
		if (t_box_code != from_box_code)
			ch = toupper(ch);
		
		answer[answer_len++] = ch;

		t = t->from;
	}

	for (int i=answer_len-1; i>=0; i--)
		printf("%c",answer[i]);
}

void solve() {
	uint init_code = encode(box_pos.code, start_pos.row, start_pos.column);

	p_read = p_write = 0;

	queue[0] = init_code;
	p_write++;

	my_ht.add(init_code, 0);

	while (p_read < p_write) {
		uint current_code = queue[p_read++];

		my_list* from = my_ht.find(current_code);

		uint box_code, x, y;
		decode(current_code, box_code, x, y);

		if (box_code == x_pos.code) {
			recover_answer(from);
			return;
		}

		for (int k=0; k<4; k++) {
			int new_x = x;
			int new_y = y;

			new_x += DX[k];
			new_y += DY[k];

			if (new_x >= 0 && new_x < n && new_y >= 0 && new_y < m) {
				if (field[new_x][new_y] == '#')
					continue;

				if (my_is_digit(field[new_x][new_y])) {
					int go_x = teleport_link[new_x][new_y].row;
					int go_y = teleport_link[new_x][new_y].column;

					uint new_code = encode(box_code, go_x, go_y);
					if (my_ht.find(new_code) == 0) {
						queue[p_write++] = new_code;
						my_ht.add(new_code, from);
					}

					continue;
				}

				if (field[new_x][new_y] == '.') {
					code_type ct;
					ct.code = box_code;

					if (ct.get_bit(new_x,new_y)) {
						//BOX!!!!!!
						int far_x = new_x + DX[k];
						int far_y = new_y + DY[k];

						if (far_x >= 0 && far_x < n && far_y >= 0 && far_y < m) {
							if (field[far_x][far_y] == '#') continue;
							if (my_is_digit(field[far_x][far_y])) continue;
							if (ct.get_bit(far_x,far_y)) continue;

							ct.set_bit(new_x,new_y,0);
							ct.set_bit(far_x,far_y,1);

							uint new_code = encode(ct.code, new_x, new_y);
							if (my_ht.find(new_code) == 0) {
								queue[p_write++] = new_code;
								my_ht.add(new_code, from);
							}
						}
					}
					else {
						uint new_code = encode(box_code, new_x, new_y);
						if (my_ht.find(new_code) == 0) {
							queue[p_write++] = new_code;
							my_ht.add(new_code, from);
						}
					}
	
					continue;
				}
			}
		}
	}

	printf("IMPOSSIBLE");
}

int main() {
	freopen("input.txt","r",stdin);
	freopen("output.txt","w",stdout);

	for (int i=0; i<10; i++)
		dig_x[i] = dig_y[i] = -1;

	gets(st);
	sscanf(st,"%d%d",&n,&m);
	for (int i=0; i<n; i++) {
		gets(st);
		for (int j=0; j<m; j++)
			if (st[j] == 's' || st[j] == 'S') {
				start_pos = point(i,j);

				if (st[j] == 'S')
					x_pos.set_bit(i,j,1);

				field[i][j] = '.';
			}
			else if (st[j] == 'b' || st[j] == 'B') {
				box_pos.set_bit(i,j,1);

				if (st[j] == 'B')
					x_pos.set_bit(i,j,1);

				field[i][j] = '.';
			}
			else if (st[j] == 'x') {
				x_pos.set_bit(i,j,1);

				field[i][j] = '.';
			}
			else if (st[j] == '.')
				field[i][j] = '.';
			else if (st[j] == '#')
				field[i][j] = '#';
			else if (my_is_digit(st[j])) {
				field[i][j] = st[j];

				if (dig_x[st[j]-'0'] == -1) {
					dig_x[st[j]-'0'] = i;
					dig_y[st[j]-'0'] = j;
				}
				else {
					teleport_link[dig_x[st[j]-'0']][dig_y[st[j]-'0']] = point(i,j);
					teleport_link[i][j] = point(dig_x[st[j]-'0'], dig_y[st[j]-'0']);
				}
			}
	}

	solve();

	return 0;
}